@@ -45,7 +45,10 @@ impl CacheBuilder {
         let opts = Options {
             path: path.as_ref().to_owned(),
             dir_depth: 2,
-            save_last_access: false,
+            track_access: false,
+
+            // default to no in-mem lru
+            lru_size: 0,
 
             // default buffer sizes to 8kb
             rbuff_sz: 8192,
@@ -71,6 +74,17 @@ impl CacheBuilder {
         self
     }
 
+    /// Sets the maximum size (in bytes) for the in-memory Least-Recently-Used cache.
+    ///
+    /// **Default is `0`**
+    ///
+    /// Setting this above `0` will create an in-memory store for recently-used entries. This will
+    /// use up more RAM, but will also significantly increase speed on memcache `HIT`s.
+    pub fn memory_lru_max_size(mut self, size: usize) -> Self {
+        self.opts.lru_size = size;
+        self
+    }
+
     /// Changes the in-memory buffer sizes for reading and writing `fs` operations.
     ///
     /// **Default is `8kb` (`8196`)**
@@ -83,6 +97,18 @@ impl CacheBuilder {
         self
     }
 
+    /// If set to `true`, this will track track the total hits and the last time an entry was
+    /// accessed in the metadata.
+    ///
+    /// **Default is `false`**
+    ///
+    /// Be warned, turning this on will cause blocking metadata database calls to occur on `read`
+    /// operations. This does not normally occur and can cause problems for `async` applications.
+    pub fn track_access(mut self, toggle: bool) -> Self {
+        self.opts.track_access = toggle;
+        self
+    }
+
     /// Builds the new [`Cache`] instance using the configured options of the builder.
     ///
     /// # Examples
