@@ -13,7 +13,9 @@
 //!
 //! - Asynchronous APIs
 //! - Fast and reliable reading/writing
+//! - Optional memory-cache layer
 //! - Tuned for large-file databases
+//! - Included cache eviction (LRU/FIFO)
 //! - Easily accessible value metadata
 //! - Optimized for cache `HIT`s
 //! - Easy error handling
@@ -31,24 +33,28 @@
 //!
 //! # Examples
 //!
-//! ```rust
-//! # #[tokio::main(flavor = "current_thread")]
-//! # async fn main() {
+//! ```rust,no_run
+//! use std::error::Error;
 //! use forceps::Cache;
 //!
-//! let cache = Cache::new("./cache")
-//!     .build()
-//!     .await
-//!     .unwrap();
+//! #[tokio::main]
+//! async fn main() -> Result<(), Box<dyn Error>> {
+//!     let cache = Cache::new("./cache")
+//!         .build()
+//!         .await?;
 //!
-//! cache.write(b"MY_KEY", b"Hello World").await.unwrap();
-//! let data = cache.read(b"MY_KEY").await.unwrap();
-//! assert_eq!(data.as_ref(), b"Hello World");
-//! # }
+//!     cache.write(b"MY_KEY", b"Hello World").await?;
+//!     let data = cache.read(b"MY_KEY").await?;
+//!     assert_eq!(data.as_ref(), b"Hello World");
+//!
+//!     Ok(())
+//! }
 //! ```
 
 #![warn(missing_docs)]
+#![warn(broken_intra_doc_links)]
 
+use std::error;
 use std::io;
 
 /// Global error type for the `forceps` crate, which is used in the `Result` types of all calls to
@@ -63,6 +69,8 @@ pub enum ForcepError {
     MetaSer(bson::ser::Error),
     /// Error with metadata sled database operation
     MetaDb(sled::Error),
+    /// The entry was found successfully, but the metadata was strangely not present
+    MetaNotFound,
     /// The entry for the specified key is not found
     NotFound,
 }
@@ -78,12 +86,25 @@ impl std::fmt::Display for ForcepError {
             Self::MetaDe(e) => write!(fmt, "there was a problem deserializing metadata: {}", e),
             Self::MetaSer(e) => write!(fmt, "there was a problem serializing metadata: {}", e),
             Self::MetaDb(e) => write!(fmt, "an error with the metadata database occurred: {}", e),
+            Self::MetaNotFound => write!(fmt, "the entry for the key provided was found, but the metadata was strangely not present"),
             Self::NotFound => write!(fmt, "the entry for the key provided was not found"),
         }
     }
 }
-impl std::error::Error for ForcepError {}
+impl error::Error for ForcepError {
+    fn source(&self) -> Option<&(dyn error::Error + 'static)> {
+        match self {
+            Self::Io(e) => Some(e),
+            Self::MetaDe(e) => Some(e),
+            Self::MetaSer(e) => Some(e),
+            Self::MetaDb(e) => Some(e),
+            Self::MetaNotFound => None,
+            Self::NotFound => None,
+        }
+    }
+}
 
+mod mem_cache;
 mod tmp;
 
 mod builder;
@@ -95,3 +116,11 @@ pub use cache::Cache;
 mod metadata;
 pub(crate) use metadata::MetaDb;
 pub use metadata::{Md5Bytes, Metadata};
+
+/// A collection of [`Cache`] eviction algorithms and generics
+///
+/// This module contains the [`Evictor`] trait, which is used to signify a structure or enum that
+/// is used to evict items out of a cache, as well as some implementations of that trait.
+///
+/// [`Evictor`]: crate::evictors::Evictor
+pub mod evictors;
